==> core-react-0.8.0.tgz: package/es/Form/FormTextarea/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';


var FormTextarea = function FormTextarea(props, context) {
  var children = props.children,
      className = props.className,
      onChange = props.onChange,
      minWidth = props.minWidth,
      minHeight = props.minHeight,
      width = props.width,
      other = _objectWithoutProperties(props, ["children", "className", "onChange", "minWidth", "minHeight", "width"]);

  var form = context.form,
      formItem = context.formItem;
  var value = form.getItemValue(formItem);

  if (!value && value !== 0) {
    value = '';
  }

  other.value = value;

  other.onChange = function (e) {
    form.setItemValue(formItem, e.target.value);
    onChange && onChange(e);
  };

  if (width) {
    other.style = Object.assign(other.style || {}, {
      width: width
    });
  }

  if (minWidth) {
    other.style = Object.assign(other.style || {}, {
      minWidth: minWidth
    });
  }

  if (minHeight) {
    other.style = Object.assign(other.style || {}, {
      minHeight: minHeight
    });
  }

  return React.createElement("textarea", _extends({
    className: cx("".concat("waui", "-form__textarea"), className)
  }, other));
};

FormTextarea.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  // onChange事件
  onChange: PropTypes.func,
  // 宽度大小，单位为px
  width: PropTypes.number,
  // 最小宽度
  minWidth: PropTypes.number,
  // 最小高度
  minHeight: PropTypes.number
};
FormTextarea.contextTypes = {
  form: PropTypes.object.isRequired,
  formItem: PropTypes.object.isRequired
};
export default FormTextarea;

==> core-react-0.8.2.tgz: package/es/Form/FormTextarea/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';


var FormTextarea = function FormTextarea(props, context) {
  var children = props.children,
      className = props.className,
      onChange = props.onChange,
      minWidth = props.minWidth,
      minHeight = props.minHeight,
      width = props.width,
      other = _objectWithoutProperties(props, ["children", "className", "onChange", "minWidth", "minHeight", "width"]);

  var form = context.form,
      formItem = context.formItem;
  var value = form.getItemValue(formItem);

  if (!value && value !== 0) {
    value = '';
  }

  other.value = value;

  other.onChange = function (e) {
    form.setItemValue(formItem, e.target.value);
    onChange && onChange(e);
  };

  if (width) {
    other.style = Object.assign(other.style || {}, {
      width: width
    });
  }

  if (minWidth) {
    other.style = Object.assign(other.style || {}, {
      minWidth: minWidth
    });
  }

  if (minHeight) {
    other.style = Object.assign(other.style || {}, {
      minHeight: minHeight
    });
  }

  return (/*#__PURE__*/React.createElement("textarea", _extends({
      className: cx("".concat("waui", "-form__textarea"), className)
    }, other))
  );
};

FormTextarea.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  // onChange事件
  onChange: PropTypes.func,
  // 宽度大小，单位为px
  width: PropTypes.number,
  // 最小宽度
  minWidth: PropTypes.number,
  // 最小高度
  minHeight: PropTypes.number
};
FormTextarea.contextTypes = {
  form: PropTypes.object.isRequired,
  formItem: PropTypes.object.isRequired
};
export default FormTextarea;
